<template>
  <el-drawer
    v-model="drawer"
    size="40%"
    title="分组列表"
    :direction="direction"
    :before-close="handleClose"
  >
    <!-- 搜索工作栏 -->
    <ContentWrap>
      <el-form
        class="-mb-15px"
        :model="queryParams"
        ref="queryFormRef"
        :inline="true"
        label-width="68px"
      >
        <el-form-item>
          <el-button
            type="primary"
            plain
            @click="openForm('create')"
            v-hasPermi="['mpk:menu:create']"
          >
            <Icon icon="ep:plus" class="mr-5px" />
            新增
          </el-button>

        </el-form-item>
      </el-form>
    </ContentWrap>

    <!-- 列表 -->
    <ContentWrap>
      <el-table
        v-loading="loading"
        :data="list"
        row-key="id"
      >
        <el-table-column prop="name" label="名称"/>
        <el-table-column prop="sort" label="排序"/>
        <el-table-column label="操作" align="center" width="200px">
          <template #default="scope">
            <div class="flex items-center justify-center">
              <el-button
                link
                type="primary"
                @click="openForm('update', scope.row.id)"
                v-hasPermi="['mpk:menu:update']"
              >
                编辑
              </el-button>
              <el-button link type="danger" @click="handleDelete(scope.row.id)" v-hasPermi="['mpk:menu:delete']">
                <Icon icon="ep:delete"/>删除
              </el-button>
            </div>
          </template>
        </el-table-column>
      </el-table>
    </ContentWrap>

    <!-- 表单弹窗：添加/修改 -->
    <GroupForm ref="formRef" @success="getList" />
  </el-drawer>
</template>
<script lang="ts" setup>
import {dateFormatter} from '@/utils/formatTime'
import * as MpkGroupApi from '@/api/model/mpk/group'
import GroupForm from './GroupForm.vue'
import type {DrawerProps} from "element-plus";

defineOptions({name: 'MpkGroup'})

const message = useMessage() // 消息弹窗
const {t} = useI18n() // 国际化

const drawer = ref(false)
const direction = ref<DrawerProps['direction']>('rtl')
const loading = ref(true) // 列表的加载中
const list = ref([]) // 字典表格数据
const queryParams = reactive({
  menuId: '',
  name: ''
})
const queryFormRef = ref() // 搜索的表单

const getList = async () => {
  loading.value = true
  try {
    const data = await MpkGroupApi.getList(queryParams)
    list.value = data
  } finally {
    loading.value = false
  }
}

/** 搜索按钮操作 */
const handleQuery = () => {
  getList()
}

/** 重置按钮操作 */
const resetQuery = () => {
  queryFormRef.value.resetFields()
  handleQuery()
}

/** 添加/修改操作 */
const formRef = ref()
const openForm = (type: string, id?: string) => {
  formRef.value.open(type, id, queryParams.menuId)
}

/** 删除按钮操作 */
const handleDelete = async (id: string) => {
  try {
    // 删除的二次确认
    await message.delConfirm()
    // 发起删除
    await MpkGroupApi.deleteGroup(id)
    message.success(t('common.delSuccess'))
    // 刷新列表
    await getList()
  } catch {
  }
}

/** 打开弹窗 */
const open = async (menuId?: string) => {
  resetForm()
  drawer.value = true
  queryParams.menuId = menuId
  if (menuId) {
    getList()
  }
}
defineExpose({open}) // 提供 open 方法，用于打开弹窗

/** 重置表单 */
const resetForm = () => {
  queryParams.menuId = ''
  queryParams.name = ''
}

const handleClose = (done: () => void) => {
  drawer.value = false
}
</script>
